@@ -9,16 +9,18 @@ use namespace::autoclean;
 
 use RapidApp::Util qw(:all);
 
+sub base :Chained :PathPrefix :CaptureArgs(0) {}
+
 # This is a special controller designed to render a single RapidApp 
 # Module in its own Viewport (i.e. in an iFrame)
 
-sub default :Path {
+sub default :Chained('base') :PathPart('') :Args {
   my ($self, $c, @args) = @_;
   # Fallback to 'direct'
   return $self->direct($c,@args);
 }
 
-sub direct :Local {
+sub direct :Chained('base') :Args {
   my ($self, $c, @args) = @_;
 
   $c->req->params->{__no_hashnav_redirect} = 1;
@@ -27,7 +29,7 @@ sub direct :Local {
   return $c->redispatch_public_path(@args);
 }
 
-sub printview :Local {
+sub printview :Chained('base') :Args {
   my ($self, $c, @args) = @_;
 
   $c->req->params->{__no_hashnav_redirect} = 1;
@@ -36,7 +38,7 @@ sub printview :Local {
   return $c->redispatch_public_path(@args);
 }
 
-sub navable :Local {
+sub navable :Chained('base') :Args {
   my ($self, $c, @args) = @_;
   
   # Return a one-off AppTab with a tab pointing to the supplied module 
