@@ -1,5 +1,16 @@
 Ext.ns('Ext.ux.RapidApp');
 
+Ext.ux.RapidApp.AppTreeLoader = Ext.extend(Ext.tree.TreeLoader,{
+  getParams: function(node) {
+    var params = Ext.ux.RapidApp.AppTreeLoader.superclass.getParams.apply(this,arguments);
+    var tp = node.getOwnerTree();
+    if(tp.root == node) {
+      params.root_node = true;
+    }
+    return params;
+  }
+});
+
 Ext.ux.RapidApp.AppTree = Ext.extend(Ext.tree.TreePanel,{
 	
 	add_node_text: 'Add',
@@ -39,6 +50,21 @@ Ext.ux.RapidApp.AppTree = Ext.extend(Ext.tree.TreePanel,{
 	debug_menu_options: false,
 	
 	initComponent: function() {
+  
+  // --------
+  // initialize the loader 
+  //   use our customized Ext.ux.RapidApp.AppTreeLoader
+  var l = this.loader;
+  if(!l){
+      l = new Ext.ux.RapidApp.AppTreeLoader({
+          dataUrl: this.dataUrl,
+          requestMethod: this.requestMethod
+      });
+  }else if(Ext.isObject(l) && !l.load){
+      l = new Ext.ux.RapidApp.AppTreeLoader(l);
+  }
+  this.loader = l;
+  // --------
 		
 		this.initDragAndDrop();
 		
@@ -191,9 +217,40 @@ Ext.ux.RapidApp.AppTree = Ext.extend(Ext.tree.TreePanel,{
 		},this);
 		
 		
+    // -----
+    // Show a load mask for the loading of the root node - GitHub #126
+    this.on('beforeload',function(node) {
+      if(node == this.root) {
+        if(!this.rootLoadMask) {
+          // For good measure, try set the mask on the parent container. This is useful
+          // because the height of TreePanel might be 0px before the root node is loaded
+          var targetCmp = this.ownerCt ? this.ownerCt : this;
+          this.rootLoadMask = new Ext.LoadMask(targetCmp.getEl(), {msg:"Loading Tree Data..."});
+        }
+        this.rootLoadMask.show(); 
+      }
+    },this);
+    
+    this.on('load',function(node) {
+      this.rootLoadMask && this.rootLoadMask.hide();
+    },this);
+    // -----
+    
+    // -- Reset node expand state on exception - GitHub Issue #127
+    this.loader.on('loadexception',function(loader,node,response){
+      if(node.expanded) { node.collapse(true); }
+      node.loaded = false;
+      node.childrenRendered = false;
+      node.ui.updateExpandIcon();
+    },this,{ delay: 50 });
 		
 		Ext.ux.RapidApp.AppTree.superclass.initComponent.call(this);
 	},
+  
+  expandChildNodes: function() {
+    if(!this.childNodes) { return; }
+    return Ext.ux.RapidApp.AppTree.superclass.expandChildNodes.apply(this,arguments);
+  },
 	
 	persistNodeExpandState: function(node,state) {
 		if(node == this.root) { return false; } // <-- ignore the root node
@@ -1192,6 +1249,11 @@ Ext.ux.RapidApp.AppTree.ServerFilterPlugin = Ext.extend(Ext.util.Observable,{
 	
 	init: function(tree) {
 		this.tree = tree;
+    
+    var Tbar = tree.getTopToolbar();
+    // New: do not load the plugin if there is no toolbar or
+    // a 'searchField' property already exists in the treepanel
+    if(!Tbar || tree.searchField) { return; }
 		
 		tree.onReload = function() {
 			delete tree.next_load_params;
@@ -1251,7 +1313,6 @@ Ext.ux.RapidApp.AppTree.ServerFilterPlugin = Ext.extend(Ext.util.Observable,{
 		}
 		
 		tree.searchField = new Ext.form.TwinTriggerField(fieldConfig);
-		var Tbar = tree.getTopToolbar();
 		Tbar.insert(this.fieldIndex,tree.searchField);
 	}
 });
@@ -1399,3 +1460,37 @@ Ext.ux.tree.TreeFilterX = Ext.extend(Ext.tree.TreeFilter, {
 
 }); // eo extend
 
+
+// ----- 
+// Overrides to prevent exceptions when panel is closed while an Ajax load is in-progress
+Ext.override(Ext.tree.TreeNode,{
+    _orig: {
+      expand: Ext.tree.TreeNode.prototype.expand,
+      expandChildNodes: Ext.tree.TreeNode.prototype.expandChildNodes,
+      renderChildren: Ext.tree.TreeNode.prototype.renderChildren,
+    },
+    expand : function(){
+      if(!this.getOwnerTree()) { return; }
+      return this._orig.expand.apply(this,arguments);
+    },
+    expandChildNodes: function() {
+      if(!this.childNodes) { return; }
+      return this._orig.expandChildNodes.apply(this,arguments);
+    },
+    renderChildren: function() {
+      if(!this.childNodes) { return; }
+      return this._orig.renderChildren.apply(this,arguments);
+    }
+});
+
+Ext.override(Ext.tree.AsyncTreeNode,{
+    loadComplete : function(deep, anim, callback, scope){
+        this.loading = false;
+        this.loaded = true;
+        if(this.ui) { this.ui.afterLoad(this); }
+        this.fireEvent("load", this);
+        this.expand(deep, anim, callback, scope);
+    }
+});
+// ----- 
+
